#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time     : 2021/8/4 9:40 上午
# @Author   : xuxiang
# @Project  : PythonSDK
# @File     : __init__.py
# @Software : PyCharm


from XuXiangPythonSDK import FileReadWrite
